import './_version.js';
/**
 * @return {boolean} Whether or not the current browser supports enabling
 * navigation preload.
 *
 * @memberof workbox-navigation-preload
 */
declare function isSupported(): boolean;
export { isSupported };
